==> 0.0.4.tar.gz: lib/remote/local/shared_prefers_helper.dart <==
import 'dart:async';
import 'dart:convert';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:sharing/remote/constants.dart';

final SharedPrefsHelper prefsHelper = SharedPrefsHelper();

class SharedPrefsHelper {
  static final instance = SharedPrefsHelper._internal();
  static SharedPreferences? _prefs;

  factory SharedPrefsHelper() => instance;

  SharedPrefsHelper._internal();

  static Future<SharedPrefsHelper> initPreferences() async {
    _prefs ??= await SharedPreferences.getInstance();
    return instance;
  }

  setDomainUrl(String value) =>
      _prefs!.setString(Constants.DOMAIN_URL_CACHE, value);

  getDomainUrl() => _prefs?.getString(Constants.DOMAIN_URL_CACHE);

  setImageUrl(String value) =>
      _prefs!.setString(Constants.IMAGE_URL_CACHE, value);

  getImageUrl() => _prefs?.getString(Constants.IMAGE_URL_CACHE);

  setPrimaryColor(String value) =>
      _prefs?.setString(Constants.PRIMARY_COLOR_CACHE, value);

  getPrimaryColor() => _prefs!.getString(Constants.PRIMARY_COLOR_CACHE);

  setPrimarySecondColor(String value) =>
      _prefs?.setString(Constants.PRIMARY_SECOND_COLOR_CACHE, value);

  getPrimarySecondColor() =>
      _prefs?.getString(Constants.PRIMARY_SECOND_COLOR_CACHE);

  setSecondColor(String value) =>
      _prefs?.setString(Constants.SECOND_COLOR_CACHE, value);

  getSecondColor() => _prefs?.getString(Constants.SECOND_COLOR_CACHE);

  setButtonColor(String value) =>
      _prefs?.setString(Constants.BUTTON_COLOR_CACHE, value);

  getButtonColor() => _prefs?.getString(Constants.BUTTON_COLOR_CACHE);

  setFontName(String? value) =>
      _prefs?.setString(Constants.FONT_CACHE, value ?? "Roboto");

  getFontName() => _prefs?.getString(Constants.FONT_CACHE) ?? "Roboto";

  setBeginColor(String value) =>
      _prefs?.setString(Constants.BEGIN_COLOR_CACHE, value);

  List<double>? getBeginColor() {
    final data = _prefs?.getString(Constants.BEGIN_COLOR_CACHE);
    if (data != null) {
      return json.decode(data);
    } else {
      return null;
    }
  }

  setEndColor(String value) =>
      _prefs?.setString(Constants.END_COLOR_CACHE, value);

  List<double>? getEndColor() {
    final data = _prefs?.getString(Constants.END_COLOR_CACHE);
    if (data != null) {
      return json.decode(data);
    } else {
      return null;
    }
  }

  clearData() {
    _prefs?.clear();
  }
}

==> 0.0.5.tar.gz: lib/remote/local/shared_prefers_helper.dart <==
import 'dart:async';
import 'dart:convert';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:sharing/common/values/colors.dart';
import 'package:sharing/remote/constants.dart';

final SharedPrefsHelper prefsHelper = SharedPrefsHelper();

class SharedPrefsHelper {
  static final instance = SharedPrefsHelper._internal();
  static SharedPreferences? _prefs;

  factory SharedPrefsHelper() => instance;

  SharedPrefsHelper._internal();

  static Future<SharedPrefsHelper> initPreferences() async {
    _prefs ??= await SharedPreferences.getInstance();
    return instance;
  }

  setDomainUrl(String value) =>
      _prefs!.setString(Constants.DOMAIN_URL_CACHE, value);

  getDomainUrl() => _prefs?.getString(Constants.DOMAIN_URL_CACHE);

  setImageUrl(String value) =>
      _prefs!.setString(Constants.IMAGE_URL_CACHE, value);

  getImageUrl() => _prefs?.getString(Constants.IMAGE_URL_CACHE);

  setPrimaryColor(String value) =>
      _prefs?.setString(Constants.PRIMARY_COLOR_CACHE, value);

  getPrimaryColor() {
    final color = _prefs!.getString(Constants.PRIMARY_COLOR_CACHE);
    if (color != null) {
      return color;
    } else {
      return SharingColors.primaryColor;
    }
  }

  setPrimarySecondColor(String value) =>
      _prefs?.setString(Constants.PRIMARY_SECOND_COLOR_CACHE, value);

  getPrimarySecondColor() {
    final color = _prefs?.getString(Constants.PRIMARY_SECOND_COLOR_CACHE);
    if (color != null) {
      return color;
    } else {
      SharingColors.primary2Color;
    }
  }

  setSecondColor(String value) =>
      _prefs?.setString(Constants.SECOND_COLOR_CACHE, value);

  getSecondColor() {
    final color = _prefs?.getString(Constants.SECOND_COLOR_CACHE);
    if (color != null) {
      return color;
    } else {
      SharingColors.secondaryColor;
    }
  }

  setButtonColor(String value) =>
      _prefs?.setString(Constants.BUTTON_COLOR_CACHE, value);

  getButtonColor() => _prefs?.getString(Constants.BUTTON_COLOR_CACHE);

  setFontName(String? value) =>
      _prefs?.setString(Constants.FONT_CACHE, value ?? "Roboto");

  getFontName() => _prefs?.getString(Constants.FONT_CACHE) ?? "Roboto";

  setBeginColor(String value) =>
      _prefs?.setString(Constants.BEGIN_COLOR_CACHE, value);

  List<double>? getBeginColor() {
    final data = _prefs?.getString(Constants.BEGIN_COLOR_CACHE);
    if (data != null) {
      return json.decode(data);
    } else {
      return null;
    }
  }

  setEndColor(String value) =>
      _prefs?.setString(Constants.END_COLOR_CACHE, value);

  List<double>? getEndColor() {
    final data = _prefs?.getString(Constants.END_COLOR_CACHE);
    if (data != null) {
      return json.decode(data);
    } else {
      return null;
    }
  }

  clearData() {
    _prefs?.clear();
  }
}
